# Getting started

There are a few different ways to install and use `Bookshelf`.
We provide these by use case below.
As a short summary, if you:

- just want to use data stored on the bookshelf,
  and nothing else, go to [for data consumers][for-data-consumers]
- want to publish a new book to the bookshelf,
  go to [for data curators][for-data-curators]
- want to develop/modify the bookshelf packages,
  go to [installation for developers][for-developers]

## By use case

---8<--- "README.md:getting-started"
